import{C as p,_ as n}from"./View.vue_vue_type_script_setup_true_lang-BhQpD6LL.js";import{a as i,ac as s,p as m,e as a,u as d}from"./jwt-decode.esm-1629-i6Y.js";import"./router-B7d52vzg.js";import"./ts.worker-LfdZp8Zr.js";import"./fetch-cPI2uPj6.js";import"./record-BHMnm12U.js";import"./SaveButton-D6_1AbA9.js";import"./ExclamationCircleOutlined-UbuQanPD.js";import"./CrudView-C4ItBtsj.js";import"./DocsButton.vue_vue_type_script_setup_true_lang-DuqPjbCt.js";import"./constants-DZMBdYj0.js";import"./url-QG2Uv9KP.js";import"./PhDotsThreeVertical.vue-BjKubw4B.js";import"./index-BBT9D1C0.js";import"./asyncComputed-C_VCJdsH.js";import"./omniChatStore-CCeDOAjZ.js";import"./uuid-BY13rHEJ.js";import"./PhCopySimple.vue-ChBQ7pI4.js";import"./PhPencil.vue-BRVITZmj.js";import"./useCodebaseEvents-CQaf5FG-.js";import"./contracts.generated-DY_ktOhZ.js";import"./index-46e9VexX.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="6c6f8b2c-3318-4e76-9275-2e36bd478dde",o._sentryDebugIdIdentifier="sentry-dbid-6c6f8b2c-3318-4e76-9275-2e36bd478dde")}catch{}})();const A=i({__name:"EnvVars",setup(o){const r=s().params.projectId,t=new p(r);return(c,f)=>(a(),m(n,{"env-var-repository":d(t),mode:"console"},null,8,["env-var-repository"]))}});export{A as default};
//# sourceMappingURL=EnvVars-DIDN_aY7.js.map
