import{_ as c}from"./Login.vue_vue_type_script_setup_true_lang-BwKTUjxd.js";import{a as p,b as u,j as i,u as n,ad as m,ac as l,e as f,aN as _}from"./jwt-decode.esm-1629-i6Y.js";import{u as g}from"./workspaceStore-bPo74WRb.js";import"./OTPInput-D3Lr3LEP.js";import"./Logo-DrvHKL7c.js";import"./string-B6y7lCY6.js";import"./CircularLoading-DyCpO3E0.js";import"./index-46e9VexX.js";import"./userStore-Ce9FjByk.js";import"./url-QG2Uv9KP.js";import"./colorHelpers-BQ7V1LXl.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="ad9dd791-398f-48aa-af09-d5697ea005ed",e._sentryDebugIdIdentifier="sentry-dbid-ad9dd791-398f-48aa-af09-d5697ea005ed")}catch{}})();const y={class:"runner"},b=p({__name:"Login",setup(e){const a=m(),o=l(),r=g(),d=async()=>{const{redirect:t,...s}=o.query;if(t){await a.push({path:t,query:s,params:o.params});return}a.push({name:"playerHome",query:s})};return(t,s)=>(f(),u("div",y,[i(c,{"logo-url":n(r).state.workspace?.logoUrl??void 0,"brand-name":n(r).state.workspace?.brandName,locale:n(r).state.workspace?.language??"en",onDone:d},null,8,["logo-url","brand-name","locale"])]))}}),L=_(b,[["__scopeId","data-v-12c690e1"]]);export{L as default};
//# sourceMappingURL=Login-rc305DQD.js.map
