.new-run-button[data-v-04e281bb]{cursor:pointer;padding:10px 12px;border-radius:8px;transition:all .2s;border:1px solid #e5e7eb;background:#fff}.new-run-button[data-v-04e281bb]:hover{background:#f9fafb;border-color:#d1d5db}.new-run-button.active[data-v-04e281bb]{background:#eff6ff;border-color:#bfdbfe;color:#1d4ed8}.icon-wrapper[data-v-04e281bb]{display:flex;align-items:center;justify-content:center;width:28px;height:28px;border-radius:6px;background:#f3f4f6}.new-run-button.active .icon-wrapper[data-v-04e281bb]{background:#dbeafe}.sidebar-run-item[data-v-04e281bb]{cursor:pointer;padding:10px 12px;border-radius:8px;margin-bottom:2px;transition:background .2s;display:flex;align-items:center}.sidebar-run-item[data-v-04e281bb]:hover,.sidebar-run-item.active[data-v-04e281bb]{background:#f3f4f6}.run-title[data-v-04e281bb]{font-size:13.5px;color:#374151;white-space:nowrap;overflow:hidden;text-overflow:ellipsis}.sidebar-run-item.active .run-title[data-v-04e281bb]{font-weight:500}.run-time[data-v-04e281bb]{font-size:11px;color:#9ca3af;flex-shrink:0}.status-dot[data-v-04e281bb]{width:8px;height:8px;border-radius:50%;flex-shrink:0}.status-dot.running[data-v-04e281bb]{background:#3b82f6;box-shadow:0 0 0 2px #3b82f61a}.status-dot.completed[data-v-04e281bb]{background:#10b981}.status-dot.failed[data-v-04e281bb]{background:#ef4444}.status-dot.pending[data-v-04e281bb]{background:#f59e0b}.status-dot.unknown[data-v-04e281bb]{background:#9ca3af}
