const __vite__mapDeps=(i,m=__vite__mapDeps,d=(m.f||(m.f=["assets/OidcLoginCallback-BRyHTNK6.js","assets/workspaceStore-bPo74WRb.js","assets/jwt-decode.esm-1629-i6Y.js","assets/jwt-decode-D9e-DIPp.css","assets/userStore-Ce9FjByk.js","assets/url-QG2Uv9KP.js","assets/colorHelpers-BQ7V1LXl.js","assets/OidcLogoutCallback-BvQFEKkl.js","assets/Login-rc305DQD.js","assets/Login.vue_vue_type_script_setup_true_lang-BwKTUjxd.js","assets/OTPInput-D3Lr3LEP.js","assets/OTPInput-C8ldH5jb.css","assets/Logo-DrvHKL7c.js","assets/Logo-D2kepPyK.css","assets/string-B6y7lCY6.js","assets/CircularLoading-DyCpO3E0.js","assets/CircularLoading-BiyobKo3.css","assets/index-46e9VexX.js","assets/Login-cMuNqCbG.css","assets/Login-C1k-SC0u.css","assets/Main-CxZPZIwm.js","assets/PlayerNavbar-bmhDTwwI.js","assets/metadata-C-jiTiZj.js","assets/PhMagnifyingGlass.vue-COMldUnu.js","assets/PhWebhooksLogo.vue-Dn9kS-5k.js","assets/LoadingOutlined-DMrD_n8o.js","assets/PhSignOut.vue-xpmgaYsB.js","assets/index-CvoJzhJS.js","assets/PlayerNavbar-VlEtzX8f.css","assets/Main-DqPmGmnC.css","assets/Home-DKTc-yoq.js","assets/Watermark-Bq8t3QJv.js","assets/constants-DZMBdYj0.js","assets/Watermark-DMbnzHiR.css","assets/PhArrowSquareOut.vue-BO7GPfoW.js","assets/index-BEMDlYDQ.js","assets/Home-B6UGln4L.css","assets/Error-CNoQ7Spi.js","assets/AbstraLogo.vue_vue_type_script_setup_true_lang-CgKXKqW-.js","assets/Error-CIbhyrKS.css","assets/Form-Bziz8xvJ.js","assets/FormRunner-BOcBstpo.js","assets/Steps-DWBLG1Jm.js","assets/index-Rgw42xFd.js","assets/Steps-DqO_G9S3.css","assets/FormRunner-61-wByB6.css","assets/redirect-8PQ7T5JL.js","assets/asyncComputed-C_VCJdsH.js","assets/uuid-BY13rHEJ.js","assets/Form-BkLIfVj9.css"])))=>i.map(i=>d[i]);
import{af as c,ag as d,ah as t,ai as m}from"./jwt-decode.esm-1629-i6Y.js";import{a as u}from"./workspaceStore-bPo74WRb.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="bebaf50e-edfa-470a-99d2-be94299e2a44",e._sentryDebugIdIdentifier="sentry-dbid-bebaf50e-edfa-470a-99d2-be94299e2a44")}catch{}})();const f=async()=>{try{const e=await fetch("/_editor/api/workspace/version");return e.ok&&(await e.json()).version||"9a203ce9f339370b3cc794555b76d6e6b059827a"}catch(e){return console.error("Failed to fetch Abstra version:",e),"9a203ce9f339370b3cc794555b76d6e6b059827a"}},p=[{path:"/oidc-login-callback",name:"oidcLoginCallback",component:()=>t(()=>import("./OidcLoginCallback-BRyHTNK6.js"),__vite__mapDeps([0,1,2,3,4,5,6])),meta:{allowUnauthenticated:!0}},{path:"/oidc-logout-callback",name:"oidcLogoutCallback",component:()=>t(()=>import("./OidcLogoutCallback-BvQFEKkl.js"),__vite__mapDeps([7,1,2,3,4,5,6])),meta:{allowUnauthenticated:!0}},{path:"/login",name:"playerLogin",component:()=>t(()=>import("./Login-rc305DQD.js"),__vite__mapDeps([8,9,2,3,1,4,5,6,10,11,12,13,14,15,16,17,18,19])),meta:{allowUnauthenticated:!0}},{path:"/",name:"main",component:()=>t(()=>import("./Main-CxZPZIwm.js"),__vite__mapDeps([20,21,4,2,3,1,5,6,22,23,24,25,26,27,28,29])),redirect:{name:"main"},children:[{path:"",name:"playerHome",component:()=>t(()=>import("./Home-DKTc-yoq.js"),__vite__mapDeps([30,22,2,3,23,24,31,1,4,5,6,32,33,34,35,25,36])),meta:{title:"Home"}},{path:"_player/threads",redirect:{name:"playerThreads"}},{path:"error/:status",name:"error",component:()=>t(()=>import("./Error-CNoQ7Spi.js"),__vite__mapDeps([37,38,12,2,3,13,32,1,4,5,6,35,39])),meta:{allowUnauthenticated:!0}},{path:":path(.*)*",name:"form",component:()=>t(()=>import("./Form-Bziz8xvJ.js"),__vite__mapDeps([40,4,2,3,41,9,1,5,6,10,11,12,13,14,15,16,17,18,42,43,44,31,32,33,45,46,47,48,49])),meta:{hideLogin:!0}}]}],o=c({history:d("/"),routes:p,scrollBehavior(e){if(e.hash)return{el:e.hash}}}),l=e=>async(a,r)=>{if(m(a,r),a.meta.allowUnauthenticated)return;const n=await u(a.path),{redirect:i,...s}=a.query;switch(n.status){case"ALLOWED":break;case"UNAUTHORIZED":await e.push({name:"playerLogin",query:{...s,redirect:i||a.path},params:a.params});break;case"NOT_FOUND":await e.push({name:"error",params:{status:"404"}});break;default:await e.push({name:"error",params:{status:"403"}})}};o.beforeEach(l(o));export{p as a,l as b,f as g,o as r};
//# sourceMappingURL=router-2BJdyI8a.js.map
