import{P as g}from"./PlayerNavbar-bmhDTwwI.js";import{a as _,ac as i,r as h,c as y,b as k,p as v,g as w,h as b,u as n,j as L,a4 as C,ad as N,e as c,aN as I}from"./jwt-decode.esm-1629-i6Y.js";import{u as V}from"./workspaceStore-bPo74WRb.js";import"./userStore-Ce9FjByk.js";import"./metadata-C-jiTiZj.js";import"./PhMagnifyingGlass.vue-COMldUnu.js";import"./PhWebhooksLogo.vue-Dn9kS-5k.js";import"./LoadingOutlined-DMrD_n8o.js";import"./PhSignOut.vue-xpmgaYsB.js";import"./index-CvoJzhJS.js";import"./url-QG2Uv9KP.js";import"./colorHelpers-BQ7V1LXl.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="20221209-f3ad-4de0-9d19-9f80f1c8f9f7",o._sentryDebugIdIdentifier="sentry-dbid-20221209-f3ad-4de0-9d19-9f80f1c8f9f7")}catch{}})();const B={class:"main-container"},D={class:"content"},R=_({__name:"Main",setup(o){const e=N(),t=V(),d=i().path,a=h(null),u=async({path:r,id:s})=>{a.value=s,await e.push({path:`/${r}`}),a.value=null},p=()=>{e.push({name:"playerLogin"})},l=()=>{e.push({name:"playerLogin"})},f=y(()=>!!i().meta.hideLogin);return(r,s)=>{const m=C("RouterView");return c(),k("div",B,[n(t).state.workspace?(c(),v(g,{key:0,"current-path":n(d),"hide-login":f.value,"runner-data":n(t).state.workspace,loading:a.value,onNavigate:u,onLoginClick:l,onLogoutClick:p},null,8,["current-path","hide-login","runner-data","loading"])):w("",!0),b("section",D,[L(m)])])}}}),G=I(R,[["__scopeId","data-v-f095bece"]]);export{G as default};
//# sourceMappingURL=Main-CxZPZIwm.js.map
