import{aR as r,aS as n,a5 as o,aT as c,aU as d,aV as p,aW as f,aX as m,aY as u,aZ as s,a_ as g,a$ as b,b0 as l}from"./jwt-decode.esm-1629-i6Y.js";import{g as y,r as i}from"./router-2BJdyI8a.js";import{s as w}from"./workspaceStore-bPo74WRb.js";import{_}from"./App.vue_vue_type_style_index_0_lang-BibO10XK.js";import"./userStore-Ce9FjByk.js";import"./url-QG2Uv9KP.js";import"./colorHelpers-BQ7V1LXl.js";import"./PlayerConfigProvider-VuTFam0u.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="191dc6a5-4dea-4f4c-9ffc-50dc6aba2d19",e._sentryDebugIdIdentifier="sentry-dbid-191dc6a5-4dea-4f4c-9ffc-50dc6aba2d19")}catch{}})();class h{static init(){setInterval(()=>{fetch("/_healthcheck").catch(()=>{})},20*1e3)}}(async()=>{await w();const e=await y(),t=r(),a=n({render:()=>o(_)});c.init(),d(a,i,e),h.init(),a.use(i),a.use(t),a.use(p),a.mount("#app"),a.component("VSelect",f),a.component("Markdown",m),a.component("Message",u),s(a,g),s(a,b),s(a,l)})();
//# sourceMappingURL=player-D6ozz9Df.js.map
